package Evo::Immune::MetaFunction;

use parent 'Evo:::GA::MetaFunction';

sub new {
	my ($class, $func) = @_;

	my $self = $class->SUPER::new($func);
}

### (partial) fitness function, sum
sub fitness_M0 ($genome, @args)
	my $idx1 = @args[0];
	my $idx2 = @args[1];
	my $sum = 0;

	for (my $i = $idx1; $i < $idx2; $i++) {
		$sum += $genome->{genes}[$i];			
	}	
	
	return $sum;
}
1;
